# Lola
### `lola` : A simple CLI for installing packages on Linux easily 

![GitHub license](https://img.shields.io/github/license/arghyagod-coder/lola)

#### Dependencies
+ click

## Installation
```bash
pip install lolacli
```

## Supported Platforms:

+ Operating System = Linux64
    - Ubuntu 20.04 and Derivatives
    - Mint 19.3
    - Mint 20.1
    - Debian 10 

## Screenshots

![](assets/help.png)

![](assets/check-apps.png)

![](assets/audacity-dl.png)

## Usage

**lola is made for linux newbies who can find it difficult to download software**

Now many will tell, Why use lola when we have those software managers?

Well, lola is a Command Line Interface and is used inside the terminal. And as we know, terminal downloads are way more faster than the software managers. While many softwares can be downloaded with a single `sudo apt install`, most common ones need some more commands.

So `lola` is here to make your life way more easier while installing software! This project targets both advanced and beginner users, because who doesn't like speedy and quicky stuff?

### What can lola do?

```bash
lola --help
```

This shows what lola can do. 
She can install apps and display a list of supported apps in current version



